summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRichard Hughes <richard@hughsie.com>2009-02-09 15:09:43 +0000
committerRichard Hughes <richard@hughsie.com>2009-02-09 15:09:43 +0000
commita7868a4564112c11320eef62e31b54d8c2c2b196 (patch)
treeb293e380a5bd12747a70c3ed67753e7b08dba50a
parent7a5fb2301f3ec2c3e3d85601410811d619925e1d (diff)
bugfix: fix the QoS interface, and abstract out the object
-rw-r--r--libdevkit-power/dkp-enum.c26
-rw-r--r--libdevkit-power/dkp-enum.h8
-rw-r--r--libdevkit-power/dkp-qos-obj.c107
-rw-r--r--libdevkit-power/dkp-qos-obj.h52
-rw-r--r--po/.gitignore1
-rw-r--r--src/dkp-qos.c66
6 files changed, 205 insertions, 55 deletions
diff --git a/libdevkit-power/dkp-enum.c b/libdevkit-power/dkp-enum.c
index be93e7e..8cdcee9 100644
--- a/libdevkit-power/dkp-enum.c
+++ b/libdevkit-power/dkp-enum.c
@@ -203,3 +203,29 @@ dkp_device_technology_from_text (const gchar *technology)
return DKP_DEVICE_TECHNOLGY_UNKNOWN;
}
+/**
+ * dkp_qos_type_to_text:
+ **/
+const gchar *
+dkp_qos_type_to_text (DkpQosType type)
+{
+ if (type == DKP_QOS_TYPE_NETWORK)
+ return "network";
+ if (type == DKP_QOS_TYPE_CPU_DMA)
+ return "cpu_dma";
+ return NULL;
+}
+
+/**
+ * dkp_qos_type_from_text:
+ **/
+DkpQosType
+dkp_qos_type_from_text (const gchar *type)
+{
+ if (egg_strequal (type, "network"))
+ return DKP_QOS_TYPE_NETWORK;
+ if (egg_strequal (type, "cpu_dma"))
+ return DKP_QOS_TYPE_CPU_DMA;
+ return DKP_QOS_TYPE_UNKNOWN;
+}
+
diff --git a/libdevkit-power/dkp-enum.h b/libdevkit-power/dkp-enum.h
index f4dc625..dc198fa 100644
--- a/libdevkit-power/dkp-enum.h
+++ b/libdevkit-power/dkp-enum.h
@@ -56,12 +56,20 @@ typedef enum {
DKP_DEVICE_TECHNOLGY_UNKNOWN
} DkpDeviceTechnology;
+typedef enum {
+ DKP_QOS_TYPE_NETWORK,
+ DKP_QOS_TYPE_CPU_DMA,
+ DKP_QOS_TYPE_UNKNOWN
+} DkpQosType;
+
const gchar *dkp_device_type_to_text (DkpDeviceType type_enum);
const gchar *dkp_device_state_to_text (DkpDeviceState state_enum);
const gchar *dkp_device_technology_to_text (DkpDeviceTechnology technology_enum);
DkpDeviceType dkp_device_type_from_text (const gchar *type);
DkpDeviceState dkp_device_state_from_text (const gchar *state);
DkpDeviceTechnology dkp_device_technology_from_text (const gchar *technology);
+const gchar *dkp_qos_type_to_text (DkpQosType type);
+DkpQosType dkp_qos_type_from_text (const gchar *type);
G_END_DECLS
diff --git a/libdevkit-power/dkp-qos-obj.c b/libdevkit-power/dkp-qos-obj.c
new file mode 100644
index 0000000..f94133e
--- /dev/null
+++ b/libdevkit-power/dkp-qos-obj.c
@@ -0,0 +1,107 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ *
+ */
+
+#include <glib.h>
+#include <glib-object.h>
+#include <string.h>
+#include <stdlib.h>
+
+#include "egg-debug.h"
+
+#include "dkp-enum.h"
+#include "dkp-qos-obj.h"
+
+/**
+ * dkp_qos_obj_clear_internal:
+ **/
+static void
+dkp_qos_obj_clear_internal (DkpQosObj *obj)
+{
+ obj->uid = 0;
+ obj->pid = 0;
+ obj->sender = NULL; /* only used in the daemon */
+ obj->cmdline = NULL;
+ obj->cookie = 0;
+ obj->timespec = 0;
+ obj->persistent;
+ obj->type = DKP_QOS_TYPE_UNKNOWN;
+ obj->value = 0;
+}
+
+/**
+ * dkp_qos_obj_copy:
+ **/
+DkpQosObj *
+dkp_qos_obj_copy (const DkpQosObj *cobj)
+{
+ DkpQosObj *obj;
+ obj = g_new0 (DkpQosObj, 1);
+ obj->cookie = cobj->cookie;
+ return obj;
+}
+
+/**
+ * dkp_qos_obj_equal:
+ **/
+gboolean
+dkp_qos_obj_equal (const DkpQosObj *obj1, const DkpQosObj *obj2)
+{
+ if (obj1->cookie == obj2->cookie)
+ return TRUE;
+ return FALSE;
+}
+
+/**
+ * dkp_qos_obj_print:
+ **/
+gboolean
+dkp_qos_obj_print (const DkpQosObj *obj)
+{
+ g_print ("cookie:%i\n", obj->cookie);
+ return TRUE;
+}
+
+/**
+ * dkp_qos_obj_new:
+ **/
+DkpQosObj *
+dkp_qos_obj_new (void)
+{
+ DkpQosObj *obj;
+ obj = g_new0 (DkpQosObj, 1);
+ dkp_qos_obj_clear_internal (obj);
+ return obj;
+}
+
+/**
+ * dkp_qos_obj_free:
+ **/
+void
+dkp_qos_obj_free (DkpQosObj *obj)
+{
+ if (obj == NULL)
+ return;
+ g_free (obj->cmdline);
+ g_free (obj->sender);
+ g_free (obj);
+ return;
+}
+
+
diff --git a/libdevkit-power/dkp-qos-obj.h b/libdevkit-power/dkp-qos-obj.h
new file mode 100644
index 0000000..63b5fb8
--- /dev/null
+++ b/libdevkit-power/dkp-qos-obj.h
@@ -0,0 +1,52 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ *
+ */
+
+#ifndef __DKP_QOS_OBJ_H__
+#define __DKP_QOS_OBJ_H__
+
+#include <glib.h>
+#include "dkp-enum.h"
+
+G_BEGIN_DECLS
+
+typedef struct
+{
+ guint uid;
+ guint pid;
+ gchar *sender; /* only used in the daemon */
+ gchar *cmdline;
+ guint cookie;
+ guint64 timespec;
+ gboolean persistent;
+ DkpQosType type;
+ gint value;
+} DkpQosObj;
+
+DkpQosObj *dkp_qos_obj_new (void);
+void dkp_qos_obj_free (DkpQosObj *obj);
+DkpQosObj *dkp_qos_obj_copy (const DkpQosObj *cobj);
+gboolean dkp_qos_obj_print (const DkpQosObj *obj);
+gboolean dkp_qos_obj_equal (const DkpQosObj *obj1,
+ const DkpQosObj *obj2);
+
+G_END_DECLS
+
+#endif /* __DKP_QOS_OBJ_H__ */
+
diff --git a/po/.gitignore b/po/.gitignore
index c4c61e6..005ab20 100644
--- a/po/.gitignore
+++ b/po/.gitignore
@@ -1,4 +1,5 @@
Makefile.in.in
POTFILES
stamp-it
+.intltool-merge-cache
diff --git a/src/dkp-qos.c b/src/dkp-qos.c
index 27abc2d..df0e5b6 100644
--- a/src/dkp-qos.c
+++ b/src/dkp-qos.c
@@ -39,6 +39,7 @@
#include "dkp-marshal.h"
#include "dkp-daemon.h"
#include "dkp-polkit.h"
+#include "dkp-qos-obj.h"
#include "dkp-qos-glue.h"
static void dkp_qos_class_init (DkpQosClass *klass);
@@ -55,28 +56,9 @@ static void dkp_qos_finalize (GObject *object);
G_TYPE_UINT64, \
G_TYPE_BOOLEAN, \
G_TYPE_STRING, \
- G_TYPE_STRING, \
G_TYPE_INT, \
G_TYPE_INVALID))
-typedef enum {
- DKP_QOS_TYPE_NETWORK,
- DKP_QOS_TYPE_CPU_DMA,
- DKP_QOS_TYPE_UNKNOWN
-} DkpQosType;
-
-typedef struct
-{
- gint value;
- guint uid;
- guint pid;
- gchar *sender;
- gchar *cmdline;
- guint32 cookie;
- gboolean persistent;
- DkpQosType type;
-} DkpQosRequestObj;
-
struct DkpQosPrivate
{
GPtrArray *data;
@@ -99,40 +81,14 @@ static guint signals [LAST_SIGNAL] = { 0 };
G_DEFINE_TYPE (DkpQos, dkp_qos, G_TYPE_OBJECT)
/**
- * dkp_qos_type_to_text:
- **/
-static const gchar *
-dkp_qos_type_to_text (DkpQosType type)
-{
- if (type == DKP_QOS_TYPE_NETWORK)
- return "network";
- if (type == DKP_QOS_TYPE_CPU_DMA)
- return "cpu_dma";
- return NULL;
-}
-
-/**
- * dkp_qos_type_from_text:
- **/
-static DkpQosType
-dkp_qos_type_from_text (const gchar *type)
-{
- if (egg_strequal (type, "network"))
- return DKP_QOS_TYPE_NETWORK;
- if (egg_strequal (type, "cpu_dma"))
- return DKP_QOS_TYPE_CPU_DMA;
- return DKP_QOS_TYPE_UNKNOWN;
-}
-
-/**
* dkp_qos_find_from_cookie:
**/
-static DkpQosRequestObj *
+static DkpQosObj *
dkp_qos_find_from_cookie (DkpQos *qos, guint32 cookie)
{
guint i;
GPtrArray *data;
- DkpQosRequestObj *obj;
+ DkpQosObj *obj;
/* search list */
data = qos->priv->data;
@@ -173,7 +129,7 @@ dkp_qos_get_lowest (DkpQos *qos, DkpQosType type)
guint i;
gint lowest = G_MAXINT;
GPtrArray *data;
- DkpQosRequestObj *obj;
+ DkpQosObj *obj;
/* find lowest */
data = qos->priv->data;
@@ -290,7 +246,7 @@ out:
void
dkp_qos_request_latency (DkpQos *qos, const gchar *type_text, gint value, gboolean persistent, DBusGMethodInvocation *context)
{
- DkpQosRequestObj *obj;
+ DkpQosObj *obj;
gchar *sender = NULL;
const gchar *auth;
gchar *cmdline = NULL;
@@ -355,7 +311,7 @@ dkp_qos_request_latency (DkpQos *qos, const gchar *type_text, gint value, gboole
}
/* seems okay, add to list */
- obj = g_new (DkpQosRequestObj, 1);
+ obj = g_new (DkpQosObj, 1);
obj->cookie = dkp_qos_generate_cookie (qos);
obj->sender = g_strdup (sender);
obj->value = value;
@@ -385,7 +341,7 @@ out:
* dkp_qos_free_data_obj:
**/
static void
-dkp_qos_free_data_obj (DkpQosRequestObj *obj)
+dkp_qos_free_data_obj (DkpQosObj *obj)
{
g_free (obj->cmdline);
g_free (obj->sender);
@@ -395,12 +351,12 @@ dkp_qos_free_data_obj (DkpQosRequestObj *obj)
/**
* dkp_qos_cancel_request:
*
* Removes a cookie and associated data from the DkpQosRequestObj struct.
**/
void
dkp_qos_cancel_request (DkpQos *qos, guint cookie, DBusGMethodInvocation *context)
{
- DkpQosRequestObj *obj;
+ DkpQosObj *obj;
GError *error;
gchar *sender = NULL;
PolKitCaller *caller = NULL;
@@ -503,7 +459,7 @@ dkp_qos_get_latency_requests (DkpQos *qos, GPtrArray **requests, GError **error)
{
guint i;
GPtrArray *data;
- DkpQosRequestObj *obj;
+ DkpQosObj *obj;
*requests = g_ptr_array_new ();
data = qos->priv->data;
@@ -542,7 +498,7 @@ dkp_qos_remove_dbus (DkpQos *qos, const gchar *sender)
{
guint i;
GPtrArray *data;
- DkpQosRequestObj *obj;
+ DkpQosObj *obj;
/* remove *any* senders that match the sender */
data = qos->priv->data;
@@ -395,12 +351,12 @@ dkp_qos_free_data_obj (DkpQosRequestObj *obj)
* dkp_qos_cancel_request:
*
- * Removes a cookie and associated data from the DkpQosRequestObj struct.
+ * Removes a cookie and associated data from the DkpQosObj struct.
**/
void